@@ -1,19 +1,22 @@
-# Copyrights 2002-2003,2007-2010 by Mark Overmeer.
+# Copyrights 2002-2020 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
-use warnings;
-use strict;
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution Hash::Case.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Hash::Case;
 use vars '$VERSION';
-$VERSION = '1.01';
+$VERSION = '1.04';
 
 
+use warnings;
+use strict;
+
 use Tie::Hash;  # contains Tie::StdHash
 use base 'Tie::StdHash';
-
-use Log::Report 'hash-case';
+use Carp qw(croak);
 
 
 sub TIEHASH(@)
@@ -32,7 +35,7 @@ sub native_init($)
        if(!$add)               { ; }
     elsif(ref $add eq 'ARRAY') { $self->addPairs(@$add) }
     elsif(ref $add eq 'HASH')  { $self->addHashData($add)  }
-    else { error "cannot initialize the native hash this way" }
+    else { croak "cannot initialize the native hash this way" }
 
     $self;
 }
@@ -46,7 +49,7 @@ sub wrapper_init($)
        if(!$add)               { ; }
     elsif(ref $add eq 'ARRAY') { $self->addPairs(@$add) }
     elsif(ref $add eq 'HASH')  { $self->setHash($add)  }
-    else { error "cannot initialize a wrapping hash this way" }
+    else { croak "cannot initialize a wrapping hash this way" }
 
     $self;
 }
