@@ -1,16 +1,21 @@
-# Copyrights 2002-2003,2007-2010 by Mark Overmeer.
+# Copyrights 2002-2020 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
-use strict;
-use warnings;
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution Hash::Case.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Hash::Case::Preserve;
 use vars '$VERSION';
-$VERSION = '1.01';
+$VERSION = '1.04';
 
 use base 'Hash::Case';
 
+use strict;
+use warnings;
+use Carp 'croak';
+
 use Log::Report 'hash-case';
 
 
@@ -24,7 +29,7 @@ sub init($)
     if($keep eq 'LAST')     { $self->{HCP_update} = 1 }
     elsif($keep eq 'FIRST') { $self->{HCP_update} = 0 }
     else
-    {   error "use 'FIRST' or 'LAST' with the option keep";
+    {   croak "use 'FIRST' or 'LAST' with the option keep";
     }
 
     $self->SUPER::native_init($args);
