@@ -1,17 +1,20 @@
-# Copyrights 2002-2003,2007-2010 by Mark Overmeer.
+# Copyrights 2002-2020 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
-use strict;
-use warnings;
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution Hash::Case.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Hash::Case::Upper;
 use vars '$VERSION';
-$VERSION = '1.01';
+$VERSION = '1.04';
 
 use base 'Hash::Case';
 
-use Log::Report 'hash-case';
+use strict;
+use warnings;
+use Carp  qw(croak);
 
 
 sub init($)
@@ -19,7 +22,7 @@ sub init($)
 
     $self->SUPER::native_init($args);
 
-    error __x"no options available for {pkg}", pkg => __PACKAGE__
+    croak "no options available for ". __PACKAGE__
         if keys %$args;
 
     $self;
